@@ -732,14 +732,16 @@ int main(int argc, char *argv[]) {
     /* exit(-1); */
   }
 
-  if(db_name[0] != '/') {  /* if not absolute pathname, tack it onto cwd */
-    getcwd(db_dir, 510);
-    strcat(db_dir, "/");
-    strcat(db_dir, db_name);
-  }
-  else { /* use the absolute pathname */
-    strcpy(db_dir, db_name);
-  }
+  /* if not absolute pathname, tack it onto cwd */
+  /*  if(db_name[0] != '/') {
+      getcwd(db_dir, 510);
+      strcat(db_dir, "/");
+      strcat(db_dir, db_name);
+      }
+      else {
+  */
+  strcpy(db_dir, db_name);
+  /*  }*/
 
   /* Initialize stuff (damn but I want a real OO language!) */
   rdi = (Retrieval_Database_Info *)malloc(sizeof(Retrieval_Database_Info));
