@@ -82,7 +82,10 @@ typedef union
 # define DST_ZONE 270
 # define DST_SUFFIX 271
 
-#include <malloc.h>
+// malloc.h also doesn't seem to be needed, and Mac OS-X has trouble finding it.
+// removed it. -- BJR 9/21/03
+// #include <malloc.h>
+
 #include <memory.h>
 #include <unistd.h>
 
